%if "%{?distro_section}" == "tainted"
%define include_patented_variants 1
%else
%define include_patented_variants 0
%endif

Name:           xboard
Version:        4.9.1
Release:        %mkrel 9
Summary:        An X Window System graphical chessboard
License:        GPLv3+
Group:          Games/Boards
URL:            https://www.gnu.org/software/xboard
Source0:        https://ftp.gnu.org/gnu/xboard/%{name}-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/xboard/%{name}-%{version}.tar.gz.sig
%if !%{include_patented_variants}
Patch1:         xboard-4.9.0-mga-remove-patented-chess-variants.patch
%endif
# (kamil) use universal xvt and not xterm for man and info help window
Patch2:         xboard-4.7.3-mga-replace-xterm-with-xvt.patch
Patch3:         xboard-4.9.1-mga-multiple-def.patch

BuildRequires:  texinfo
BuildRequires:	pkgconfig(cairo) >= 1.2.0
BuildRequires:	pkgconfig(librsvg-2.0) >= 2.14.0
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	gettext-devel
BuildRequires:	xdg-utils
Requires:       xorg-x11-fonts
# default chess engine
Recommends:       fairymax
# to play sounds
Recommends:       alsa-utils
# for UCI chess engines
Recommends:       polyglot

%description
XBoard is a graphical user interface for chess in all its major forms,
including international chess, xiangqi (Chinese chess), shogi (Japanese chess)
and Makruk, in addition to many minor variants such as Losers Chess,
Crazyhouse, Chess960 and Capabanca Chess. It displays a chessboard on the
screen, accepts moves made with the mouse, and loads and saves games in
Portable Game Notation (PGN). It serves as a front-end for many different chess
services, including:
- Chess engines that will run on your machine and play a game against you or
help you analyze, such as GNU Chess, Crafty, or many others.
- Chess servers on the Internet, where you can connect to play chess with
people from all over the world, watch other users play, or just hang out and
chat.
- Correspondence chess played by electronic mail. The CMail program automates
the tasks of parsing email from your opponent, playing his moves out on your
board, and mailing your reply move after you've chosen it.

XBoard runs on Unix and Unix-like systems that use the X Window System.

XBoard is built with zippy.

%if %include_patented_variants
Gothic Chess is protected by U.S. patent #6,481,716 by Ed Trice.
Falcon Chess is protected by U.S. patent #5,690,334 by George W. Duke
%endif


%prep
%autosetup -p1

%build
autoreconf -fi
%configure --bindir=%{_gamesbindir} --with-gtk
%make_build

%install
%make_install

install -m 0755 -p cmail %{buildroot}%{_gamesbindir}

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING COPYRIGHT NEWS README SHORTLOG TODO zippy.README
%doc *.txt *.html
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_gamesbindir}/cmail
%{_gamesbindir}/%{name}
%{_gamesdatadir}/%{name}/
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_infodir}/%{name}.info*
%{_mandir}/man6/%{name}.6*
%config(noreplace) %{_sysconfdir}/%{name}.conf


%changelog
* Thu Jul 03 2025 umeabot <umeabot> 4.9.1-9.mga10
+ Revision: 2244499
- Mageia 10 Mass Rebuild

* Fri Jun 27 2025 umeabot <umeabot> 4.9.1-8.mga10.tainted
+ Revision: 2212732
- Mageia 10 Mass Rebuild

* Wed Mar 30 2022 umeabot <umeabot> 4.9.1-7.mga9.tainted
+ Revision: 1834670
- Mageia 9 Mass Rebuild

* Thu Aug 20 2020 ovitters <ovitters> 4.9.1-6.mga8.tainted
+ Revision: 1616884
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Wed Aug 05 2020 joequant <joequant> 4.9.1-5.mga8
+ Revision: 1611141
- update deps

* Fri May 15 2020 danf <danf> 4.9.1-4.mga8.tainted
+ Revision: 1583999
- Switch http: URLs to https:
- Fix multiple definition error with gcc 10.1

* Fri Feb 14 2020 umeabot <umeabot> 4.9.1-3.mga8.tainted
+ Revision: 1519165
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 4.9.1-2.mga7
+ Revision: 1301809
- Mageia 7 Mass Rebuild

* Sun Jan 29 2017 akien <akien> 4.9.1-1.mga6.tainted
+ Revision: 1084152
- Version 4.9.1

* Thu May 26 2016 akien <akien> 4.9.0-2.mga6.tainted
+ Revision: 1018649
- Rebuild for tainted/release (BS bug)

* Thu May 26 2016 akien <akien> 4.9.0-1.1.mga6
+ Revision: 1018645
- Rebuild for core/release (BS bug)

* Thu May 26 2016 akien <akien> 4.9.0-1.mga6.tainted
+ Revision: 1018640
- Rediff P1 removing patented chess variants
- Version 4.9.0

* Tue Feb 09 2016 umeabot <umeabot> 4.8.0-2.mga6.tainted
+ Revision: 950996
- Mageia 6 Mass Rebuild

* Sun Nov 30 2014 cjw <cjw> 4.8.0-1.mga5.tainted
+ Revision: 800033
- add BuildRequires: gettext-devel
- 4.8.0
- switch to GTK (fixes font problem, mga#13810)

* Wed Oct 15 2014 umeabot <umeabot> 4.7.3-4.mga5.tainted
+ Revision: 742285
- Second Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat Aug 16 2014 akien <akien> 4.7.3-3.mga5.tainted
+ Revision: 663889
- Rediff and reapply Patch1 and Patch2

* Sat Feb 15 2014 dams <dams> 4.7.3-2.mga5.tainted
+ Revision: 592066
- new version 4.7.3

* Mon Oct 21 2013 umeabot <umeabot> 4.7.2-2.mga4.tainted
+ Revision: 536922
- Mageia 4 Mass Rebuild

* Wed Sep 25 2013 fwang <fwang> 4.7.2-1.mga4
+ Revision: 485882
- update file list
- update file list
- update file list
- update desktop file
- new version 4.7.2

* Mon Jan 14 2013 umeabot <umeabot> 4.6.2-5.mga3.tainted
+ Revision: 386635
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 4.6.2-4.mga3.tainted
+ Revision: 324892
- rebuild for Mga3 Beta1

* Wed Jul 25 2012 kamil <kamil> 4.6.2-3.mga3.tainted
+ Revision: 274361
- suggest polyglot - a chess engine protocol translator

* Mon May 28 2012 kamil <kamil> 4.6.2-2.mga3.tainted
+ Revision: 247734
- drop P0 from this package (again)

* Mon May 28 2012 kamil <kamil> 4.6.2-1.mga3.tainted
+ Revision: 247720
- new version 4.6.2
- rediff P1, P2
- drop P0, it's already announced in GUI and man

* Sat Mar 10 2012 kamil <kamil> 4.5.3-4.mga2.tainted
+ Revision: 222381
- add P2 -mga-replace-xterm-with-xvt.patch (use an universal terminal for man and info window invocation

* Mon Jan 09 2012 kamil <kamil> 4.5.3-3.mga2.tainted
+ Revision: 194245
- fix creation of symlink of the man-page of cmail
- rename patches to fit policies
- clean spec

* Fri Oct 14 2011 kamil <kamil> 4.5.3-2.mga2.tainted
+ Revision: 155273
- xboard suggests alsa-util to play sounds
- xboard requires xorg-x11-fonts (100dpi or 75dpi) instead of only 100dpi
- fairymax (a chess engine) and xterm (x terminal emulator) are now suggested

* Tue Oct 04 2011 kamil <kamil> 4.5.3-1.mga2.tainted
+ Revision: 151546
- New version 4.5.3

* Sat Sep 24 2011 obgr_seneca <obgr_seneca> 4.5.2a-1.mga2.tainted
+ Revision: 147370
- new version 4.5.2a
- now licensed under GPLv3+
- description updated
- requirements updated
- default chess engine updated - changed from GNU Chess (gnuchess) to Fairy-Max (fairymax)
- man page cmail.6* is symliked to the xboard.6* man page
- this package provides cmail
- disable all partly suported board sizes
- SPEC file provided by Kamil Rytarowski
- clean up

* Sun May 15 2011 pterjan <pterjan> 4.2.7-15.mga1
+ Revision: 99043
- Rebuild for fixed find-requires

* Wed Apr 27 2011 wally <wally> 4.2.7-14.mga1
+ Revision: 92042
- fix desktop file name (mga#954)
- drop buildroot definition
- fix exec line in desktop file

* Wed Mar 16 2011 steletch <steletch> 4.2.7-13.mga1
+ Revision: 72896
- Clean spec file
- imported package xboard


* Fri Dec 03 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 4.2.7-13mdv2011.0
+ Revision: 606899
- Replace X11-devel BR for libxaw-devel
- Update package URL (moved)

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 4.2.7-12mdv2010.1
+ Revision: 524372
- rebuilt for 2010.1

* Sat Mar 28 2009 Funda Wang <fwang@mandriva.org> 4.2.7-11mdv2009.1
+ Revision: 361873
- rediff entry patch
- fix str fmt

  + Antoine Ginies <aginies@mandriva.com>
    - rebuild

* Thu Jun 12 2008 Pixel <pixel@mandriva.com> 4.2.7-10mdv2009.0
+ Revision: 218426
- rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Wed Mar 05 2008 Oden Eriksson <oeriksson@mandriva.com> 4.2.7-10mdv2008.1
+ Revision: 179545
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - buildrequires X11-devel instead of XFree86-devel

* Thu Aug 30 2007 Adam Williamson <awilliamson@mandriva.org> 4.2.7-9mdv2008.0
+ Revision: 76357
- rebuild for 2008
- don't package COPYING
- correct xdg menu categories
- use Fedora license policy
- bunzip2 patches
- Import xboard



* Fri Sep  1 2006 Olivier Blin <blino@mandriva.com> 4.2.7-8mdv2007.0
- XDG menu

* Sun Jan 01 2006 Mandriva Linux Team <http://www.mandrivaexpert.com/> 4.2.7-7mdk
- Rebuild

* Thu Jul 14 2005 Abel Cheung <deaddog@mandriva.org> 4.2.7-6mdk
- Extend wrapper to launch sjeng too if other engines are not found

* Fri Jun 03 2005 Abel Cheung <deaddog@mandriva.org> 4.2.7-5mdk
- Extend wrapper to launch phalanx too if gnuchess not found
- Use small board by default, to fit small screens (Conectiva)
- Source2: pxboard man page (Debian)
- Source3: X resource file that adds tooltip to buttons, and adds
  3D feel even to Xaw widgets, without need of Xaw3d! (Conectiva)
- Patch1: properly quote variables inside cmail (Debian)
- Patch2: display timer in another color if time is tight (Debian)
- Patch3: use xvt script instead of xterm to display manpage/info
- Patch4: allow changing the label of some buttons (Conectiva)
- Patch5: highlight legal moves and threatened pieces, modified from
  http://members.optushome.com.au/stelliosk/xboard/

* Mon Aug 16 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 4.2.7-4mdk
- Rebuild with new menu

* Sat Aug 07 2004 Abel Cheung <deaddog@deaddog.org> 4.2.7-3mdk
- Requires chessengine instead of gnuchess only
- Wrapper script becomes longer, so place it in another file

* Thu Jul 15 2004 Michael Scherer <misc@mandrake.org> 4.2.7-2mdk 
- correct Requires

* Tue Dec 02 2003 Abel Cheung <deaddog@deaddog.org> 4.2.7-1mdk
- 4.2.7

* Wed Nov 19 2003 Abel Cheung <deaddog@deaddog.org> 4.2.6-8mdk
- Remove patch1 (gnuchessx is back)
- Add missing BuildRequires

* Wed Nov 12 2003 Guillaume Cottenceau <gc@mandrakesoft.com> 4.2.6-7mdk
- fix Olivier Thauvin not even testing his package :) (#6320)

* Thu Oct 30 2003 Olivier Thauvin <thauvin@aerov.jussieu.fr> 4.2.6-6mdk
- use %%_gamesbindir
- add wrapper to xboard to set correct path

* Thu Apr 24 2003 Guillaume Cottenceau <gc@mandrakesoft.com> 4.2.6-5mdk
- fix %%doc section thx to stefan's robot

* Sat Jul 20 2002 Daouda LO <daouda@mandrakesoft.com> 4.2.6-4mdk
- apply patch from Olivier Thauvin

* Fri Mar 01 2002 David BAUDENS <baudens@mandrakesoft.com> 4.2.6-3mdk
- Don't hardcode icon PATH in menu
- Use standard boards_section.png for icons (so don't break E menu)

* Wed Feb 06 2002 Geoffrey Lee <snailtalk@mandrakesoft.com> 4.2.6-2mdk
- Use License: tag (sorry I missed that on first try).

* Wed Feb 06 2002 Geoffrey Lee <snailtalk@mandrakesoft.com> 4.2.6-1mdk
- 4.2.6 out for general consumption.
- Add a URL.

* Tue May  8 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 4.2.3-1mdk
- version 4.2.3

* Wed Feb 07 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 4.2.2-1mdk
- another new and shiny source.

* Tue Feb 06 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 4.2.1-1mdk
- new and shiny source.

* Sun Oct 29 2000 Geoffrey Lee <snailtalk@mandrakesoft.com> 4.1.0-1mdk
- new and shiny source.

* Wed Aug 16 2000 David BAUDENS <baudens@mandrakesoft.com> 4.0.7-5mdk
- Fix menu entry

* Wed Aug 16 2000 Enzo Maggi <enzo@mandrakesoft.com> 4.0.7-4mdk
- Minor bug fix in the spec

* Tue Aug 14 2000 Enzo Maggi <enzo@mandrakesoft.com> 4.0.7-3mdk
- introduced the %%{_mandir}, %%{_bindir}, %%{_infodir} etc.

* Mon Aug 07 2000 Frederic Lepied <flepied@mandrakesoft.com> 4.0.7-2mdk
- automatically added BuildRequires

* Thu Jun 13 2000 Florin Grad <florin@mandrakesoft.com> 4.0.7-1mdk
- "new" release

* Fri May 05 2000 Florin Grad <florin@mandrakesoft.com> 4.0.5-2mdk
- fix the menu integration

* Sat Apr 08 2000 Christopher Molnar <molnarc@mandrakesoft.com> 4.0.5-1mdk
- Updated to 4.0.5
- New groups
- Added docs
- added menu funtions to spec file

* Fri Nov 12 1999 Damien Kroktine <damien@mandrakesoft.com>
- Mandrake release

* Wed Sep  8 1999 Bill Nottingham <notting@redhat.com>
- update to 4.0.3

* Sat Aug 14 1999 Bill Nottingham <notting@redhat.com>
- change requires: to virtual 'chessprogram'

* Thu Aug 12 1999 Bill Nottingham <notting@redhat.com>
- require gnuchess so it will work out of the box

* Fri Jul 30 1999 Bill Nottingham <notting@redhat.com>
- update to 4.0.2

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 3)

* Thu Dec 17 1998 Michael Maher <mike@redhat.com>
- cleaned up spec file
- built package for 6.0

* Sat Jul 11 1998 Mike Wangsmo <wanger@redhat.com>
- updated to a new version
- buildrooted the package too

* Fri May 01 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr
